\name{tp}
\alias{tp}
\alias{tp2}
\alias{tp_it}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Dimension Estimation via Translated Poisson Distributions }
\description{
Estimates the intrinsic dimension of a data set using models of translated
Poisson distributions. \code{tp} employs an approximation to avoid iteration
(see Haro el al. (2008)), \code{tp_it} does five iterations to get the result.
}
\usage{
tp(data, indexes = 1:dim(data)[1], k, dnoise, sigma, n, 
   loc = FALSE, verbose = FALSE)
tp2(data, indexes = 1:dim(data)[1], k, dnoise, sigma, n,
    loc = FALSE, verbose = FALSE)
tp_it(data, indexes = 1:dim(data)[1], k, dnoise, sigma, n,
      init = 5, loc = FALSE, verbose = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{data set with each row describing a data point.}
  \item{indexes}{the indexes of the data points for which local dimension
    estimation should be made.}
  \item{k}{the number of neighbors that should be used for dimension estimation
    for each point.}
  \item{dnoise}{a function or a name of a function giving the translation density.}
  \item{sigma}{(estimated) standard deviation of the (isotropic) noise.}
  \item{n}{dimension of the noise.}
  \item{init}{initial value for iterative procedure.}
  \item{loc}{ should local estimates be returned?}
  \item{verbose}{should intermediate estimates be printed out?}
}
\details{
  \code{tp} uses the same approximation as Haro et al. (2008) of a certain
  integral, \code{tp2} multiplies the integrand with \code{r}, which guarantees
  that the integral converges. However, the approximation in \code{tp2} does not
  result in error terms that are symmetric around \code{r} as in \code{tp}. 
}
\value{
  If \code{loc = FALSE} a vector with two components:
  \item{de}{the overall dimension estimate}
  \item{likelihood}{this is \code{NA} in the current implementation.}
  If \code{loc = FALSE} a matrix with two columns corresponding to the two components above.
  Row \code{i} corresponds to local dimension estimate at point \code{data[indexes[i], ]}.
}
\references{
  Haro, G., Randall, G. and Sapiro, G. (2008) Translated Poisson Mixture Model
  for Stratification Learning. \emph{Int. J. Comput. Vis.}, \bold{80}, 358-374.
}
\author{
Kerstin Johnsson, Lund University.
}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{tp_glob}}, \code{\link{tp_loc}}
}
\examples{
require(manifgen)
data <- hball(1000, d = 7, n = 13, sd = 0.01)
tp(data, 1:100, 10, dnoiseGaussH, 0.01, 13)
tp(data, 1:100, 10, dnoiseNcChi, 0.01, 13)
tp2(data, 1:100, 10, dnoiseGaussH, 0.01, 13)
tp2(data, 1:100, 10, dnoiseNcChi, 0.01, 13)
tp_it(data, 1:100, 10, dnoiseGaussH, 0.01, 13)
tp_it(data, 1:100, 10, dnoiseNcChi, 0.01, 13)

}
%\keyword{ ~kwd1 }
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
